#
# Conditional build:
%bcond_without	apidocs		# gtk-doc based API documentation
%bcond_without	static_libs	# static library
%bcond_without	tpm2		# TPM2 support
%bcond_without	vala            # Vala API

Summary:	Library for storing and retrieving passwords and other secrets
Summary(pl.UTF-8):	Biblioteka do przechowywania i odczytu haseł oraz innych tajnych informacji
Name:		libsecret
Version:	0.20.5
Release:	1
License:	LGPL v2.1+
Group:		Libraries
Source0:	https://download.gnome.org/sources/libsecret/0.20/%{name}-%{version}.tar.xz
# Source0-md5:	5c9e5a011852c82fa9ed9e61ba91efb5
URL:		https://wiki.gnome.org/Projects/Libsecret
BuildRequires:	gettext-tools >= 0.19.8
%{?with_apidocs:BuildRequires:	gi-docgen >= 2021.7}
BuildRequires:	glib2-devel >= 1:2.44.0
BuildRequires:	gobject-introspection-devel >= 1.29
BuildRequires:	libgcrypt-devel >= 1.2.2
BuildRequires:	libxslt-progs
BuildRequires:	meson >= 0.50
BuildRequires:	ninja >= 1.5
BuildRequires:	pkgconfig
BuildRequires:	rpm-build >= 4.6
BuildRequires:	rpmbuild(macros) >= 1.746
BuildRequires:	tar >= 1:1.22
%{?with_tpm2:BuildRequires:	tpm2-tss-devel >= 3.0.3}
%{?with_vala:BuildRequires:	vala >= 2:0.17.2.12}
BuildRequires:	xz
Requires:	glib2 >= 1:2.44.0
Requires:	libgcrypt >= 1.2.2
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
libsecret is a library for storing and retrieving passwords and other
secrets. It communicates with the "Secret Service" using DBus.
gnome-keyring and KSecretService are both implementations of a Secret
Service.

%description -l pl.UTF-8
libsecret to biblioteka do przechowywania i odczytu haseł oraz innych
tajnych informacji. Komunikuje się z usługą informacji tajnych
("Secret Service") poprzez DBus. Zarówno gnome-keyring, jak i
KSecretService są implementacjami tej usługi.

%package devel
Summary:	Header files for libsecret library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki libsecret
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	glib2-devel >= 1:2.38.0
Requires:	libgcrypt-devel >= 1.2.2

%description devel
Header files for libsecret library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki libsecret.

%package static
Summary:	Static libsecret library
Summary(pl.UTF-8):	Statyczna biblioteka libsecret
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static libsecret library.

%description static -l pl.UTF-8
Statyczna biblioteka libsecret.

%package apidocs
Summary:	libsecret API documentation
Summary(pl.UTF-8):	Dokumentacja API biblioteki libsecret
Group:		Documentation
BuildArch:	noarch

%description apidocs
libsecret API documentation.

%description apidocs -l pl.UTF-8
Dokumentacja API biblioteki libsecret.

%package -n vala-libsecret
Summary:	libsecret API for Vala language
Summary(pl.UTF-8):	API libsecret dla języka Vala
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}
Requires:	vala >= 2:0.17.2.12
BuildArch:	noarch

%description -n vala-libsecret
libsecret API for Vala language.

%description -n vala-libsecret -l pl.UTF-8
API libsecret dla języka Vala.

%prep
%setup -q

%build
%meson build \
	%{!?with_static_libs:--default-library=shared} \
	-Dbashcompdir=%{bash_compdir} \
	%{!?with_apidocs:-Dgtk_doc=false} \
	%{?with_tpm2:-Dtpm2=true} \
	%{!?with_vala:-Dvapi=false}

%ninja_build -C build

%install
rm -rf $RPM_BUILD_ROOT

%ninja_install -C build

%if %{with apidocs}
# FIXME: where to package gi-docgen generated docs?
install -d $RPM_BUILD_ROOT%{_gtkdocdir}
%{__mv} $RPM_BUILD_ROOT%{_docdir}/libsecret-1 $RPM_BUILD_ROOT%{_gtkdocdir}/libsecret
%endif

%{__rm} -r $RPM_BUILD_ROOT%{_localedir}/ab

%find_lang libsecret

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files -f libsecret.lang
%defattr(644,root,root,755)
%doc NEWS README.md
%attr(755,root,root) %{_bindir}/secret-tool
%attr(755,root,root) %{_libdir}/libsecret-1.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libsecret-1.so.0
%{_libdir}/girepository-1.0/Secret-1.typelib
%{_mandir}/man1/secret-tool.1*

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libsecret-1.so
%{_includedir}/libsecret-1
%{_pkgconfigdir}/libsecret-1.pc
%{_pkgconfigdir}/libsecret-unstable.pc
%{_datadir}/gir-1.0/Secret-1.gir

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libsecret-1.a
%endif

%if %{with apidocs}
%files apidocs
%defattr(644,root,root,755)
%{_gtkdocdir}/%{name}
%endif

%if %{with vala}
%files -n vala-libsecret
%defattr(644,root,root,755)
%{_datadir}/vala/vapi/libsecret-1.deps
%{_datadir}/vala/vapi/libsecret-1.vapi
%endif
%changelog
* Mon Feb 21 2022 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/libsecret.git;a=log;h=master

* Mon Feb 21 2022 Jakub Bogusz <qboosh@pld-linux.org> 5aa132e
- updated to 0.20.5, uses meson + gi-docgen now
- remove unsupported ab locale

* Sun Feb 28 2021 Jan Rękorajski <baggins@pld-linux.org> 1bb6b04
- unconditional noarch subpackages

* Sat Oct 10 2020 Jan Palus <atler@pld-linux.org> c9f72ae
- up to 0.20.4

* Fri Apr 24 2020 Jan Palus <atler@pld-linux.org> 3277e3a
- up to 0.20.3

* Thu Mar 12 2020 Jan Palus <atler@pld-linux.org> 46ec1ff
- up to 0.20.2

* Sun Feb 16 2020 Jakub Bogusz <qboosh@pld-linux.org> d938ccb
- updated to 0.20.1

* Tue Jan 14 2020 Jakub Bogusz <qboosh@pld-linux.org> da844fc
- updated to 0.20.0

* Sat Apr 13 2019 Jakub Bogusz <qboosh@pld-linux.org> 29dfcbe
- working URL (live.gnome.org had wrong redirection)

* Sat Apr 13 2019 Jakub Bogusz <qboosh@pld-linux.org> c63e0b3
- drop .la file; release 3

* Sat Apr 13 2019 Jakub Bogusz <qboosh@pld-linux.org> aa213a3
- updated URL

* Thu Mar 14 2019 Jan Palus <atler@pld-linux.org> 75fcd0c
- release 2 (by relup.sh)

* Sun Mar 03 2019 Jan Palus <atler@pld-linux.org> cd97829
- up to 0.18.8

* Wed Jan 09 2019 Jan Palus <atler@pld-linux.org> 7e43fa5
- up to 0.18.7

* Sat Oct 27 2018 Jakub Bogusz <qboosh@pld-linux.org> aae7999
- added sh patch (don't use non-standard $'...' expansion)

* Sat Mar 31 2018 Marcin Banasiak <marcin.banasiak@gmail.com> ac667c2
- Update to 0.18.6

* Mon Mar 28 2016 Elan Ruusamäe <glen@delfi.ee> 999793b
- noarch vala subpackage

* Fri Mar 25 2016 Marcin Banasiak <marcin.banasiak@gmail.com> 48071b7
- Update to 0.18.5

* Fri Jan 22 2016 Jakub Bogusz <qboosh@pld-linux.org> af03eaa
- updated to 0.18.4

* Sat Aug 22 2015 Łukasz Kieś <kiesiu@pld-linux.org> f338ae3
- updated to 0.18.3

* Tue Apr 21 2015 Marcin Banasiak <marcin.banasiak@gmail.com> fd78422
- Update to 0.18.2

